@@ -32,18 +32,16 @@
 #define snprintf _snprintf
 #endif  
 
-using namespace std;
-
 namespace varconf {
 
-Variable::Variable()
+VarBase::VarBase()
  : m_have_bool(false), m_have_int(false), m_have_double(false),
    m_have_string(false), m_val_bool(false), m_val_int(0), m_val_double(0.0),
    m_val("")
 {
 }
 
-Variable::Variable(const Variable& c)
+VarBase::VarBase(const VarBase& c)
  : m_have_bool(c.m_have_bool), m_have_int(c.m_have_int),
    m_have_double(c.m_have_double), m_have_string(c.m_have_string),
    m_val_bool(c.m_val_bool), m_val_int(c.m_val_int),
@@ -51,14 +49,14 @@ Variable::Variable(const Variable& c)
 {
 }
 
-Variable::Variable(const bool b)
+VarBase::VarBase(const bool b)
  : m_have_bool(true), m_have_int(false), m_have_double(false),
    m_have_string(true), m_val_bool(b), m_val_int(0), m_val_double(0.0)
 {
   m_val = (b ? "true" : "false");
 }
 
-Variable::Variable(const int i)
+VarBase::VarBase(const int i)
  : m_have_bool(false), m_have_int(true), m_have_double(false),
    m_have_string(true), m_val_bool(false), m_val_int(i), m_val_double(0.0)
 {
@@ -67,7 +65,7 @@ Variable::Variable(const int i)
   m_val = buf;
 }
 
-Variable::Variable(const double d)
+VarBase::VarBase(const double d)
  : m_have_bool(false), m_have_int(false), m_have_double(true),
    m_have_string(true), m_val_bool(false), m_val_int(0), m_val_double(d)
 {
@@ -76,21 +74,21 @@ Variable::Variable(const double d)
   m_val = buf;
 }
 
-Variable::Variable(const string& s)
+VarBase::VarBase(const std::string& s)
  : m_have_bool(false), m_have_int(false), m_have_double(false),
    m_have_string(true), m_val_bool(false), m_val_int(0), m_val_double(0.0),
    m_val(s)
 {
 }
 
-Variable::Variable(const char* s)
+VarBase::VarBase(const char* s)
  : m_have_bool(false), m_have_int(false), m_have_double(false),
    m_have_string(true), m_val_bool(false), m_val_int(0), m_val_double(0.0),
    m_val(s)
 {
 }
 
-ostream& operator<<( ostream& out, const Variable& v)
+std::ostream& operator<<( std::ostream& out, const VarBase& v)
 {
     for (size_t i = 0; i < v.m_val.size(); i++) {
       if (v.m_val[i] == '"') out << '\\';
@@ -99,7 +97,7 @@ ostream& operator<<( ostream& out, const Variable& v)
     return out;
 }
 
-bool operator ==( const Variable& one, const Variable& two)
+bool operator ==( const VarBase& one, const VarBase& two)
 {
   if ( one.m_have_bool == two.m_have_bool &&
        one.m_have_int == two.m_have_int &&
@@ -114,7 +112,7 @@ bool operator ==( const Variable& one, const Variable& two)
   return false;
 }
 
-Variable& Variable::operator=( const Variable& c)
+VarBase& VarBase::operator=( const VarBase& c)
 {
   if (&c == this) return (*this);
   m_have_bool = c.m_have_bool; m_have_int = c.m_have_int;
@@ -124,7 +122,7 @@ Variable& Variable::operator=( const Variable& c)
   return (*this);
 }
 
-Variable& Variable::operator=(const bool b)
+VarBase& VarBase::operator=(const bool b)
 {
   m_have_bool = true; m_have_int = false;
   m_have_double = false; m_have_string = true;
@@ -133,7 +131,7 @@ Variable& Variable::operator=(const bool b)
   return (*this);
 }
 
-Variable& Variable::operator=(const int i)
+VarBase& VarBase::operator=(const int i)
 {
   m_have_bool = false; m_have_int = true;
   m_have_double = false; m_have_string = true;
@@ -144,7 +142,7 @@ Variable& Variable::operator=(const int i)
   return (*this);
 }
 
-Variable& Variable::operator=(const double d)
+VarBase& VarBase::operator=(const double d)
 {
   m_have_bool = false; m_have_int = false;
   m_have_double = true; m_have_string = true;
@@ -155,7 +153,7 @@ Variable& Variable::operator=(const double d)
   return (*this);
 }
 
-Variable& Variable::operator=(const string& s)
+VarBase& VarBase::operator=(const std::string& s)
 {
   m_have_bool = false; m_have_int = false;
   m_have_double = false; m_have_string = true;
@@ -164,7 +162,16 @@ Variable& Variable::operator=(const string& s)
   return (*this);
 }
 
-Variable::operator bool()
+VarBase& VarBase::operator=(const char* s)
+{
+  m_have_bool = false; m_have_int = false;
+  m_have_double = false; m_have_string = true;
+  m_val_bool = false; m_val_int = 0;
+  m_val_double = 0.0; m_val = s;
+  return (*this);
+}
+
+VarBase::operator bool()
 {
   if (!m_have_bool) {
     if ((m_val == "on") || (m_val == "1") || (m_val == "true") || (m_val ==
@@ -174,7 +181,7 @@ Variable::operator bool()
   return m_val_bool;
 }
 
-Variable::operator int()
+VarBase::operator int()
 {
   if (!m_have_int) {
     m_val_int = atoi(m_val.c_str());
@@ -183,7 +190,7 @@ Variable::operator int()
   return m_val_int;
 }
 
-Variable::operator double()
+VarBase::operator double()
 {
   if (!m_have_double) {
     m_val_double = atof(m_val.c_str());
@@ -192,12 +199,12 @@ Variable::operator double()
   return m_val_double;
 }
 
-Variable::operator string()
+VarBase::operator std::string()
 {
   return m_val;
 }
 
-bool Variable::is_bool()
+bool VarBase::is_bool()
 {
   if (!is_string()) return false;
   if ( (m_val == "on") || (m_val == "off")
@@ -208,7 +215,7 @@ bool Variable::is_bool()
      ) return true; else return false;
 }
 
-bool Variable::is_int()
+bool VarBase::is_int()
 {
   if (!is_string()) return false;
   for (size_t i = 0; i < m_val.size(); i++) if (!isdigit(m_val[i]))
@@ -216,27 +223,140 @@ bool Variable::is_int()
   return true;
 }
 
-bool Variable::is_double()
+bool VarBase::is_double()
 {
   if (!is_string()) return false;
 
   char* p;
-  char* tmp = new char[m_val.size()+1];
-  size_t i;
-  for (i = 0; i < m_val.size(); i++) tmp[i] = m_val[i];
-  m_val[i] = 0;
-  strtod(tmp, &p);
-  if (tmp == p) {
-    delete [] tmp;
-    return false;
-  }
-  delete [] tmp;
-  return true;
+
+  // strtod() points p to the first character
+  // in the string that doesn't look like
+  // part of a double
+  strtod(m_val.c_str(), &p);
+
+  return p == m_val.c_str() + m_val.size();
 }
 
-bool Variable::is_string()
+bool VarBase::is_string()
 {
   return m_have_string;
 }
 
+Variable::Variable (const Variable& c) : VarPtr(c.is_array()
+  ? VarPtr(new VarArray(*(c.array()))) : static_cast<const VarPtr&>(c))
+{
+
+}
+
+Variable::Variable( const int n, const Variable& v)
+  : VarPtr(new VarArray(n, v))
+{
+
+}
+
+Variable::Variable( const VarList& v) : VarPtr(new VarArray(v))
+{
+
+}
+
+Variable& Variable::operator=( const Variable& c)
+{
+  VarList *array_val = c.array();
+
+  if(array_val) // Equivalent to c.is_array()
+    VarPtr::operator=(new VarArray(*array_val));
+  else
+    VarPtr::operator=(c);
+  return *this;
+}
+
+Variable& Variable::operator=( VarBase* vb)
+{
+  VarPtr::operator=(vb);
+  return *this;
+}
+
+Variable& Variable::operator=( const bool b)
+{
+  VarPtr::operator=(new VarBase(b));
+  return *this;
+}
+
+Variable& Variable::operator=( const int i)
+{
+  VarPtr::operator=(new VarBase(i));
+  return *this;
+}
+
+Variable& Variable::operator=( const double d)
+{
+  VarPtr::operator=(new VarBase(d));
+  return *this;
+}
+
+Variable& Variable::operator=( const std::string& s)
+{
+  VarPtr::operator=(new VarBase(s));
+  return *this;
+}
+
+Variable& Variable::operator=( const char* s)
+{
+  VarPtr::operator=(new VarBase(s));
+  return *this;
+}
+
+Variable& Variable::operator=( const VarList& v)
+{
+  VarPtr::operator=(new VarArray(v));
+  return *this;
+}
+
+Variable& Variable::operator[](const int i)
+{
+  std::vector<Variable> *the_array = array();
+
+  if(!the_array) {
+    VarArray *new_array = new VarArray(i + 1);
+    (*new_array)[0] = *this;
+    VarPtr::operator=(new_array);
+    the_array = new_array;
+  }
+  else if (the_array->size() < i + 1)
+    the_array->resize(i + 1);
+
+  return (*the_array)[i];
+}
+
+
+std::ostream& operator<<( std::ostream& out, const VarArray& v)
+{
+  out << "(";
+
+  VarArray::const_iterator i = v.begin();
+  while(true) {
+    out << *i;
+    if(++i == v.end())
+      break;
+    out << ",";
+  }
+
+  out << ")";
+  return out;
+}
+
+bool operator ==( const VarArray& one, const VarArray& two)
+{
+  if(one.size() != two.size())
+    return false;
+
+  VarArray::const_iterator i1, i2;
+
+  for(i1 = one.begin(), i2 = two.begin(); i1 != one.end(); ++i1, ++i2)
+    if(i1->elem() != i2->elem())
+      return false;
+
+  return true;
+}
+
 } // namespace varconf
